@@ -3,6 +3,8 @@ use super::{
     constants, extensions::Extensions, seq_iter::SeqIter, visitor::impl_visitor, HandleOwned,
 };
 
+use core::fmt;
+
 use serde::de::{Deserializer, Error, Unexpected};
 use serde::Deserialize;
 use ssh_format::from_bytes;
@@ -18,7 +20,11 @@ impl ServerVersion {
     /// * `bytes` - should not include the initial 4-byte which server
     ///   as the length of the whole packet.
     pub fn deserialize(bytes: &[u8]) -> ssh_format::Result<Self> {
-        let (version, mut bytes) = from_bytes(bytes)?;
+        let ((packet_type, version), mut bytes): ((u8, _), _) = from_bytes(bytes)?;
+
+        if packet_type != constants::SSH_FXP_VERSION {
+            return Err(ssh_format::Error::custom("Unexpected response"));
+        }
 
         let mut strings = StringsNoIndex::new();
         while !bytes.is_empty() {
@@ -210,6 +216,17 @@ impl ErrMsg {
     }
 }
 
+impl fmt::Display for ErrMsg {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let (err_msg, language_tag) = self.get();
+        write!(
+            f,
+            "Err Message: {}, Language Tag: {}",
+            err_msg, language_tag
+        )
+    }
+}
+
 /// Entry in ResponseInner::Name
 #[derive(Debug, Deserialize, Clone)]
 pub struct NameEntry {
